pandas\.io\.formats\.style\.Styler\.background\_gradient
========================================================

.. currentmodule:: pandas.io.formats.style

.. automethod:: Styler.background_gradient